/*
 * #%L
 * Nuiton Processor :: Api
 * 
 * $Id: LogsProcessor.java 377 2011-02-03 10:40:42Z tchemit $
 * $HeadURL: http://svn.nuiton.org/svn/processor/tags/processor-1.2/nuiton-processor/src/main/java/org/nuiton/processor/LogsProcessor.java $
 * %%
 * Copyright (C) 2002 - 2010 CodeLutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as 
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 * 
 * You should have received a copy of the GNU General Lesser Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/lgpl-3.0.html>.
 * #L%
 */


/* *
* LogsProcessor.java
*
* Created: Wed Jan 14 2004
*
* @author  <poussin@codelutin.com>
* Copyright Code Lutin
* @version $Revision: 377 $
*
* Mise a jour: $Date: 2011-02-03 11:40:42 +0100 (Thu, 03 Feb 2011) $
* par : $Author: tchemit $
*/

package org.nuiton.processor;

import org.nuiton.processor.filters.ActiveLogsCodeFilter;
import org.nuiton.processor.filters.RemoveLogsCodeFilter;

import java.io.Console;

/*
* This class is a processor for source logs
*/
public class LogsProcessor extends Processor {
    private static final String REMOVE_ACTION = "remove";

    private static final String ACTIVE_ACTION = "active";

    public enum Action {
        NoAction,
        Logs,
        NoLogsCode
    }

    public LogsProcessor(Action action) {
        switch (action) {

            case NoAction:
                // No action is the default filter in Processor
                break;

            case Logs:
                // Go for logs
                setInputFilter(new ActiveLogsCodeFilter());
                break;

            case NoLogsCode:
                setInputFilter(new RemoveLogsCodeFilter());
                break;
        }
    }

    public static void main(String[] args) throws Exception {
        Console console = System.console();
        String eol = System.getProperty("line.separator");
        if (args.length < 2) {
            console.printf("Give source and destination file, then action" + eol);
            console.printf("Action may be remove or active (default is no action)" + eol);
            return;
        }
        Action action = Action.NoAction;
        if (args.length > 2) {
            if (args[2].equals(REMOVE_ACTION)) {
                action = Action.NoLogsCode;
                console.printf("Removing logs code" + eol);
            } else if (args[2].equals(ACTIVE_ACTION)) {
                action = Action.Logs;
                console.printf("Setting logs active" + eol);
            }
        }

        if (action == Action.NoAction) {
            console.printf("No action taken" + eol);
        }

        LogsProcessor processor = new LogsProcessor(action);
        ProcessorUtil.doProcess(processor, args[0], args[1], ProcessorUtil.DEFAULT_ENCODING);
    }
}
